@@ -14,13 +14,13 @@
     };
     int main()
     {
-        cout << "Word '" << max(string("first"), string("second")) <<
+        cout << "Word '" << max("first"s, "second"s) <<
                                     "' is lexicographically last\n";
 
-        cout << "Word '" << max(string("first"), string("SECOND")) <<
+        cout << "Word '" << max("first"s, "SECOND"s) <<
                                     "' is lexicographically last\n";
 
-        cout << "Word '" << max(string("first"), string("SECOND"),
+        cout << "Word '" << max("first"s, "SECOND"s,
                             CaseString{}) << "' is lexicographically last\n";
     }
     /*
