@@ -9,5 +9,5 @@ class Class
 int main()
 {
     Class one;
-    Class two(one);
+    Class two{ one };
 }
