@@ -9,11 +9,11 @@
             IntArray(size_t size = 1);
             IntArray(IntArray const &other);
             ~IntArray();
-            IntArray const &operator=(IntArray const &other);
+            IntArray &operator=(IntArray const &other);
 
                                                 // overloaded index operators:
-            int &operator[](size_t index);                // first
-            int const &operator[](size_t index) const;    // second
+            int &operator[](size_t index);              // first
+            int operator[](size_t index) const;         // second
 
             void swap(IntArray &other);         // trivial
 
